==> haskell-crypto-token-0.1.2-8.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.2
visibility:           public
id:                   crypto-token-0.1.2-IQscVG2wpVu806DTaWJZS
key:                  crypto-token-0.1.2-IQscVG2wpVu806DTaWJZS
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  18cc43906d35fa3689e841e40ef2687e
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.2-IQscVG2wpVu806DTaWJZS
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-token-0.1.2-9-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.1.2
visibility:           public
id:                   crypto-token-0.1.2-2d88nFd0vTmHgdc2NliHLH
key:                  crypto-token-0.1.2-2d88nFd0vTmHgdc2NliHLH
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  777b8b51264c38e955f586629f613d05
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-token-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.1.2-2d88nFd0vTmHgdc2NliHLH
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
